@@ -11,21 +11,24 @@ typedef Eo Efl_Access_Object;
 #ifndef _EFL_ACCESS_OBJECT_EO_TYPES
 #define _EFL_ACCESS_OBJECT_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Type of accessibility object
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_Type
  */
 typedef enum
 {
-  EFL_ACCESS_TYPE_REGULAR = 0, /**< default accessibile object */
+  EFL_ACCESS_TYPE_REGULAR = 0, /**< default accessible object */
   EFL_ACCESS_TYPE_DISABLED, /**< skip object and its children in accessibility
                              * hierarchy */
   EFL_ACCESS_TYPE_SKIPPED /**< skip object in accessibility hierarchy */
 } Efl_Access_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Describes the role of an object visible to Accessibility Clients.
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_Role
  */
 typedef enum
 {
@@ -134,90 +137,96 @@ typedef enum
   EFL_ACCESS_ROLE_INFO_BAR, /**< Role: info bar */
   EFL_ACCESS_ROLE_LAST_DEFINED /**< Last enum entry sentinel */
 } Efl_Access_Role;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Describes the possible states for an object visible to accessibility
  * clients.
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_State_Type
  */
 typedef enum
 {
-  EFL_ACCESS_STATE_INVALID = 0, /**< State: invalid */
-  EFL_ACCESS_STATE_ACTIVE, /**< State: active */
-  EFL_ACCESS_STATE_ARMED, /**< State: armed */
-  EFL_ACCESS_STATE_BUSY, /**< State: busy */
-  EFL_ACCESS_STATE_CHECKED, /**< State: checked */
-  EFL_ACCESS_STATE_COLLAPSED, /**< State: collapsed */
-  EFL_ACCESS_STATE_DEFUNCT, /**< State: defunct */
-  EFL_ACCESS_STATE_EDITABLE, /**< State: editable */
-  EFL_ACCESS_STATE_ENABLED, /**< State: enabled */
-  EFL_ACCESS_STATE_EXPANDABLE, /**< State: expandable */
-  EFL_ACCESS_STATE_EXPANDED, /**< State: expanded */
-  EFL_ACCESS_STATE_FOCUSABLE, /**< State: focusable */
-  EFL_ACCESS_STATE_FOCUSED, /**< State: focused */
-  EFL_ACCESS_STATE_HAS_TOOLTIP, /**< State: has a tooltip */
-  EFL_ACCESS_STATE_HORIZONTAL, /**< State: horizontal */
-  EFL_ACCESS_STATE_ICONIFIED, /**< State: iconified */
-  EFL_ACCESS_STATE_MODAL, /**< State: modal */
-  EFL_ACCESS_STATE_MULTI_LINE, /**< State: multi line */
-  EFL_ACCESS_STATE_MULTISELECTABLE, /**< State: multiselectable */
-  EFL_ACCESS_STATE_OPAQUE, /**< State: opaque */
-  EFL_ACCESS_STATE_PRESSED, /**< State: pressed */
-  EFL_ACCESS_STATE_RESIZABLE, /**< State: resizable */
-  EFL_ACCESS_STATE_SELECTABLE, /**< State: selectable */
-  EFL_ACCESS_STATE_SELECTED, /**< State: selected */
-  EFL_ACCESS_STATE_SENSITIVE, /**< State: sensitive */
-  EFL_ACCESS_STATE_SHOWING, /**< State: showing */
-  EFL_ACCESS_STATE_SINGLE_LINE, /**< State: single line */
-  EFL_ACCESS_STATE_STALE, /**< State: stale */
-  EFL_ACCESS_STATE_TRANSIENT, /**< State: transient */
-  EFL_ACCESS_STATE_VERTICAL, /**< State: vertical */
-  EFL_ACCESS_STATE_VISIBLE, /**< State: visible */
-  EFL_ACCESS_STATE_MANAGES_DESCENDANTS, /**< State: manage descendants */
-  EFL_ACCESS_STATE_INDETERMINATE, /**< State: indeterminate */
-  EFL_ACCESS_STATE_REQUIRED, /**< State: required */
-  EFL_ACCESS_STATE_TRUNCATED, /**< State: truncated */
-  EFL_ACCESS_STATE_ANIMATED, /**< State: animated */
-  EFL_ACCESS_STATE_INVALID_ENTRY, /**< State: invalid entry */
-  EFL_ACCESS_STATE_SUPPORTS_AUTOCOMPLETION, /**< State: supports autocompletion
-                                             */
-  EFL_ACCESS_STATE_SELECTABLE_TEXT, /**< State: selectable text */
-  EFL_ACCESS_STATE_IS_DEFAULT, /**< State: is default */
-  EFL_ACCESS_STATE_VISITED, /**< State: visited */
-  EFL_ACCESS_STATE_LAST_DEFINED /**< Last enum entry sentinel */
+  EFL_ACCESS_STATE_TYPE_INVALID = 0, /**< State: invalid */
+  EFL_ACCESS_STATE_TYPE_ACTIVE, /**< State: active */
+  EFL_ACCESS_STATE_TYPE_ARMED, /**< State: armed */
+  EFL_ACCESS_STATE_TYPE_BUSY, /**< State: busy */
+  EFL_ACCESS_STATE_TYPE_CHECKED, /**< State: checked */
+  EFL_ACCESS_STATE_TYPE_COLLAPSED, /**< State: collapsed */
+  EFL_ACCESS_STATE_TYPE_DEFUNCT, /**< State: defunct */
+  EFL_ACCESS_STATE_TYPE_EDITABLE, /**< State: editable */
+  EFL_ACCESS_STATE_TYPE_ENABLED, /**< State: enabled */
+  EFL_ACCESS_STATE_TYPE_EXPANDABLE, /**< State: expandable */
+  EFL_ACCESS_STATE_TYPE_EXPANDED, /**< State: expanded */
+  EFL_ACCESS_STATE_TYPE_FOCUSABLE, /**< State: focusable */
+  EFL_ACCESS_STATE_TYPE_FOCUSED, /**< State: focused */
+  EFL_ACCESS_STATE_TYPE_HAS_TOOLTIP, /**< State: has a tooltip */
+  EFL_ACCESS_STATE_TYPE_HORIZONTAL, /**< State: horizontal */
+  EFL_ACCESS_STATE_TYPE_MINIMIZED, /**< State: minimized */
+  EFL_ACCESS_STATE_TYPE_MODAL, /**< State: modal */
+  EFL_ACCESS_STATE_TYPE_MULTI_LINE, /**< State: multi line */
+  EFL_ACCESS_STATE_TYPE_MULTISELECTABLE, /**< State: multiselectable */
+  EFL_ACCESS_STATE_TYPE_OPAQUE, /**< State: opaque */
+  EFL_ACCESS_STATE_TYPE_PRESSED, /**< State: pressed */
+  EFL_ACCESS_STATE_TYPE_RESIZABLE, /**< State: resizable */
+  EFL_ACCESS_STATE_TYPE_SELECTABLE, /**< State: selectable */
+  EFL_ACCESS_STATE_TYPE_SELECTED, /**< State: selected */
+  EFL_ACCESS_STATE_TYPE_SENSITIVE, /**< State: sensitive */
+  EFL_ACCESS_STATE_TYPE_SHOWING, /**< State: showing */
+  EFL_ACCESS_STATE_TYPE_SINGLE_LINE, /**< State: single line */
+  EFL_ACCESS_STATE_TYPE_STALE, /**< State: stale */
+  EFL_ACCESS_STATE_TYPE_TRANSIENT, /**< State: transient */
+  EFL_ACCESS_STATE_TYPE_VERTICAL, /**< State: vertical */
+  EFL_ACCESS_STATE_TYPE_VISIBLE, /**< State: visible */
+  EFL_ACCESS_STATE_TYPE_MANAGES_DESCENDANTS, /**< State: manage descendants */
+  EFL_ACCESS_STATE_TYPE_INDETERMINATE, /**< State: indeterminate */
+  EFL_ACCESS_STATE_TYPE_REQUIRED, /**< State: required */
+  EFL_ACCESS_STATE_TYPE_TRUNCATED, /**< State: truncated */
+  EFL_ACCESS_STATE_TYPE_ANIMATED, /**< State: animated */
+  EFL_ACCESS_STATE_TYPE_INVALID_ENTRY, /**< State: invalid entry */
+  EFL_ACCESS_STATE_TYPE_SUPPORTS_AUTOCOMPLETION, /**< State: supports
+                                                  * autocompletion */
+  EFL_ACCESS_STATE_TYPE_SELECTABLE_TEXT, /**< State: selectable text */
+  EFL_ACCESS_STATE_TYPE_IS_DEFAULT, /**< State: is default */
+  EFL_ACCESS_STATE_TYPE_VISITED, /**< State: visited */
+  EFL_ACCESS_STATE_TYPE_LAST_DEFINED /**< Last enum entry sentinel */
 } Efl_Access_State_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Describes the relationship between two objects.
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_Relation_Type
  */
 typedef enum
 {
-  EFL_ACCESS_RELATION_NULL = 0, /**< No relation */
-  EFL_ACCESS_RELATION_LABEL_FOR, /**< Label for relation */
-  EFL_ACCESS_RELATION_LABELLED_BY, /**< Labelled by relation */
-  EFL_ACCESS_RELATION_CONTROLLER_FOR, /**< Controller for relation */
-  EFL_ACCESS_RELATION_CONTROLLED_BY, /**< Controlled by relation */
-  EFL_ACCESS_RELATION_MEMBER_OF, /**< Member of relation */
-  EFL_ACCESS_RELATION_TOOLTIP_FOR, /**< Tooltip for relation */
-  EFL_ACCESS_RELATION_NODE_CHILD_OF, /**< Node child of relation */
-  EFL_ACCESS_RELATION_NODE_PARENT_OF, /**< Node parent of relation */
-  EFL_ACCESS_RELATION_EXTENDED, /**< Extended relation */
-  EFL_ACCESS_RELATION_FLOWS_TO, /**< Flows to relation */
-  EFL_ACCESS_RELATION_FLOWS_FROM, /**< Flows from relation */
-  EFL_ACCESS_RELATION_SUBWINDOW_OF, /**< Subwindow of relation */
-  EFL_ACCESS_RELATION_EMBEDS, /**< Embeds relation */
-  EFL_ACCESS_RELATION_EMBEDDED_BY, /**< Embedded by relation */
-  EFL_ACCESS_RELATION_POPUP_FOR, /**< Popup for relation */
-  EFL_ACCESS_RELATION_PARENT_WINDOW_OF, /**< Parent window of relation */
-  EFL_ACCESS_RELATION_DESCRIPTION_FOR, /**< Description for relation */
-  EFL_ACCESS_RELATION_DESCRIBED_BY, /**< Described by relation */
-  EFL_ACCESS_RELATION_LAST_DEFINED /**< Last enum entry sentinel */
+  EFL_ACCESS_RELATION_TYPE_NULL = 0, /**< No relation */
+  EFL_ACCESS_RELATION_TYPE_LABEL_FOR, /**< Label for relation */
+  EFL_ACCESS_RELATION_TYPE_LABELLED_BY, /**< Labelled by relation */
+  EFL_ACCESS_RELATION_TYPE_CONTROLLER_FOR, /**< Controller for relation */
+  EFL_ACCESS_RELATION_TYPE_CONTROLLED_BY, /**< Controlled by relation */
+  EFL_ACCESS_RELATION_TYPE_MEMBER_OF, /**< Member of relation */
+  EFL_ACCESS_RELATION_TYPE_TOOLTIP_FOR, /**< Tooltip for relation */
+  EFL_ACCESS_RELATION_TYPE_NODE_CHILD_OF, /**< Node child of relation */
+  EFL_ACCESS_RELATION_TYPE_NODE_PARENT_OF, /**< Node parent of relation */
+  EFL_ACCESS_RELATION_TYPE_EXTENDED, /**< Extended relation */
+  EFL_ACCESS_RELATION_TYPE_FLOWS_TO, /**< Flows to relation */
+  EFL_ACCESS_RELATION_TYPE_FLOWS_FROM, /**< Flows from relation */
+  EFL_ACCESS_RELATION_TYPE_SUBWINDOW_OF, /**< Subwindow of relation */
+  EFL_ACCESS_RELATION_TYPE_EMBEDS, /**< Embeds relation */
+  EFL_ACCESS_RELATION_TYPE_EMBEDDED_BY, /**< Embedded by relation */
+  EFL_ACCESS_RELATION_TYPE_POPUP_FOR, /**< Popup for relation */
+  EFL_ACCESS_RELATION_TYPE_PARENT_WINDOW_OF, /**< Parent window of relation */
+  EFL_ACCESS_RELATION_TYPE_DESCRIPTION_FOR, /**< Description for relation */
+  EFL_ACCESS_RELATION_TYPE_DESCRIBED_BY, /**< Described by relation */
+  EFL_ACCESS_RELATION_TYPE_LAST_DEFINED /**< Last enum entry sentinel */
 } Efl_Access_Relation_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** The accessible Reading information type that can be read.
  *
- * @ingroup Efl_Access_Reading_Info
+ * @ingroup Efl_Access_Reading_Info_Type
  */
 typedef enum
 {
@@ -229,32 +238,40 @@ typedef enum
   EFL_ACCESS_READING_INFO_TYPE_STATE = 8 /* 1 >> 3 */ /**< State should be read.
                                                        */
 } Efl_Access_Reading_Info_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility object state set.
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_State_Set
  */
 typedef uint64_t Efl_Access_State_Set;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility event listener
  *
- * @ingroup Efl_Access_Event
+ * @ingroup Efl_Access_Event_Handler
  */
 typedef struct _Efl_Access_Event_Handler Efl_Access_Event_Handler;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility state changed event data
  *
- * @ingroup Efl_Access_Event_State_Changed
+ * @ingroup Efl_Access_Event_State_Changed_Data
  */
 typedef struct _Efl_Access_Event_State_Changed_Data
 {
   Efl_Access_State_Type type; /**< Type of the state changed event */
   Eina_Bool new_value; /**< New value */
 } Efl_Access_Event_State_Changed_Data;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility geometry changed event data
  *
- * @ingroup Efl_Access_Event_Geometry_Changed
+ * @ingroup Efl_Access_Event_Geometry_Changed_Data
  */
 typedef struct _Efl_Access_Event_Geometry_Changed_Data
 {
@@ -263,39 +280,47 @@ typedef struct _Efl_Access_Event_Geometry_Changed_Data
   int width; /**< Width */
   int height; /**< Height */
 } Efl_Access_Event_Geometry_Changed_Data;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility children changed event data
  *
- * @ingroup Efl_Access_Event_Children_Changed
+ * @ingroup Efl_Access_Event_Children_Changed_Data
  */
 typedef struct _Efl_Access_Event_Children_Changed_Data
 {
   Eina_Bool is_added; /**< Child is added or not */
   Efl_Object *child; /**< Child object */
 } Efl_Access_Event_Children_Changed_Data;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility Attribute
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_Attribute
  */
 typedef struct _Efl_Access_Attribute
 {
   const char *key; /**< Attribute key */
   const char *value; /**< Attribute value */
 } Efl_Access_Attribute;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility Relation
  *
- * @ingroup Efl_Access
+ * @ingroup Efl_Access_Relation
  */
 typedef struct _Efl_Access_Relation
 {
   Efl_Access_Relation_Type type; /**< Relation type */
   Eina_List *objects; /**< List with relation objects */
 } Efl_Access_Relation;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Accessibility accessible mixin
  *
  * @ingroup Efl_Access_Object
@@ -304,7 +329,7 @@ typedef struct _Efl_Access_Relation
 
 EWAPI const Efl_Class *efl_access_object_mixin_get(void);
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Gets an localized string describing accessible object role name.
@@ -317,9 +342,9 @@ EWAPI const Efl_Class *efl_access_object_mixin_get(void);
  */
 EOAPI const char *efl_access_object_localized_role_name_get(const Eo *obj);
 #endif
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Accessible name of the object.
  *
@@ -329,9 +354,9 @@ EOAPI const char *efl_access_object_localized_role_name_get(const Eo *obj);
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_i18n_name_set(Eo *obj, const char *i18n_name);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Accessible name of the object.
  *
@@ -342,9 +367,9 @@ EOAPI void efl_access_object_i18n_name_set(Eo *obj, const char *i18n_name);
  * @ingroup Efl_Access_Object
  */
 EOAPI const char *efl_access_object_i18n_name_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Gets an all relations between accessible object and other accessible
@@ -356,11 +381,11 @@ EOAPI const char *efl_access_object_i18n_name_get(const Eo *obj);
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Eina_Iterator *efl_access_object_relations_get(const Eo *obj);
-#endif
+EOAPI Eina_Iterator *efl_access_object_relations_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The role of the object in accessibility domain.
  *
@@ -370,9 +395,9 @@ EOAPI Eina_Iterator *efl_access_object_relations_get(const Eo *obj);
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_role_set(Eo *obj, Efl_Access_Role role);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The role of the object in accessibility domain.
  *
@@ -383,9 +408,9 @@ EOAPI void efl_access_object_role_set(Eo *obj, Efl_Access_Role role);
  * @ingroup Efl_Access_Object
  */
 EOAPI Efl_Access_Role efl_access_object_role_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Gets object's accessible children.
@@ -396,14 +421,14 @@ EOAPI Efl_Access_Role efl_access_object_role_get(const Eo *obj);
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Eina_List *efl_access_object_access_children_get(const Eo *obj);
-#endif
+EOAPI Eina_List *efl_access_object_access_children_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Gets human-readable string indentifying object accessibility role.
+ * @brief Gets human-readable string identifying object accessibility role.
  *
  * @param[in] obj The object.
  *
@@ -413,23 +438,23 @@ EOAPI Eina_List *efl_access_object_access_children_get(const Eo *obj);
  */
 EOAPI const char *efl_access_object_role_name_get(const Eo *obj);
 #endif
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Gets key-value pairs indentifying object extra attributes. Must be
+ * @brief Gets key-value pairs identifying object extra attributes. Must be
  * free by a user.
  *
  * @param[in] obj The object.
  *
- * @return List of object attributes, Must be freed by the user
+ * @return List of object attributes. Must be freed by the user
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Eina_List *efl_access_object_attributes_get(const Eo *obj);
-#endif
+EOAPI Eina_List *efl_access_object_attributes_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
 /**
  * @brief Add key-value pair identifying object extra attributes
@@ -443,10 +468,17 @@ EOAPI Eina_List *efl_access_object_attributes_get(const Eo *obj);
 EOAPI void efl_access_object_attribute_append(Eo *obj, const char *key, const char *value);
 
 /**
- * @brief Removes all attributes in accessible object.
+ * @brief delete key-value pair identifying object extra attributes when key is
+ * given
  *
- * @internal
  * @param[in] obj The object.
+ * @param[in] key The string key to identify the key-value pair
+ *
+ * @ingroup Efl_Access_Object
+ */
+EOAPI void efl_access_object_attribute_del(Eo *obj, const char *key);
+
+/** Removes all attributes in accessible object.
  *
  * @ingroup Efl_Access_Object
  */
@@ -454,7 +486,11 @@ EOAPI void efl_access_object_attributes_clear(Eo *obj);
 
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Sets reading information of an accessible object.
+ * @brief Reading information of an accessible object.
+ *
+ * If no reading information is set, 0 is returned which means all four reading
+ * information types will be read from object highlight. If set to 0, existing
+ * reading info will be deleted.
  *
  * @param[in] obj The object.
  * @param[in] reading_info Reading information types
@@ -466,7 +502,11 @@ EOAPI void efl_access_object_reading_info_type_set(Eo *obj, Efl_Access_Reading_I
 
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Gets reading information types of an accessible object.
+ * @brief Reading information of an accessible object.
+ *
+ * If no reading information is set, 0 is returned which means all four reading
+ * information types will be read from object highlight. If set to 0, existing
+ * reading info will be deleted.
  *
  * @param[in] obj The object.
  *
@@ -477,7 +517,7 @@ EOAPI void efl_access_object_reading_info_type_set(Eo *obj, Efl_Access_Reading_I
 EOAPI Efl_Access_Reading_Info_Type efl_access_object_reading_info_type_get(const Eo *obj);
 #endif
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Gets index of the child in parent's children list.
@@ -490,9 +530,9 @@ EOAPI Efl_Access_Reading_Info_Type efl_access_object_reading_info_type_get(const
  */
 EOAPI int efl_access_object_index_in_parent_get(const Eo *obj);
 #endif
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Contextual information about object.
  *
@@ -502,9 +542,9 @@ EOAPI int efl_access_object_index_in_parent_get(const Eo *obj);
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_description_set(Eo *obj, const char *description);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Contextual information about object.
  *
@@ -515,9 +555,9 @@ EOAPI void efl_access_object_description_set(Eo *obj, const char *description);
  * @ingroup Efl_Access_Object
  */
 EOAPI const char *efl_access_object_description_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Gets set describing object accessible states.
@@ -530,9 +570,9 @@ EOAPI const char *efl_access_object_description_get(const Eo *obj);
  */
 EOAPI Efl_Access_State_Set efl_access_object_state_set_get(const Eo *obj);
 #endif
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Register accessibility event listener
@@ -544,11 +584,11 @@ EOAPI Efl_Access_State_Set efl_access_object_state_set_get(const Eo *obj);
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Efl_Access_Event_Handler *efl_access_object_event_handler_add(const Eo *obj, Efl_Event_Cb cb, void *data);
-#endif
+EOAPI Efl_Access_Event_Handler *efl_access_object_event_handler_add(Efl_Event_Cb cb, void *data);
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Deregister accessibility event listener
@@ -557,11 +597,11 @@ EOAPI Efl_Access_Event_Handler *efl_access_object_event_handler_add(const Eo *ob
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI void efl_access_object_event_handler_del(const Eo *obj, Efl_Access_Event_Handler *handler);
-#endif
+EOAPI void efl_access_object_event_handler_del(Efl_Access_Event_Handler *handler);
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
  * @brief Emit event
@@ -572,16 +612,16 @@ EOAPI void efl_access_object_event_handler_del(const Eo *obj, Efl_Access_Event_H
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI void efl_access_object_event_emit(const Eo *obj, Efl_Access_Object *accessible, const Efl_Event_Description *event, void *event_info);
-#endif
+EOAPI void efl_access_object_event_emit(Efl_Access_Object *accessible, const Efl_Event_Description *event, void *event_info);
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The translation domain of "name" and "description" properties.
  *
  * Translation domain should be set if the application wants to support i18n
- * for accessibily "name" and "description" properties.
+ * for accessibility "name" and "description" properties.
  *
  * When translation domain is set, values of "name" and "description"
  * properties will be translated with the dgettext function using the current
@@ -597,14 +637,14 @@ EOAPI void efl_access_object_event_emit(const Eo *obj, Efl_Access_Object *access
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_translation_domain_set(Eo *obj, const char *domain);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The translation domain of "name" and "description" properties.
  *
  * Translation domain should be set if the application wants to support i18n
- * for accessibily "name" and "description" properties.
+ * for accessibility "name" and "description" properties.
  *
  * When translation domain is set, values of "name" and "description"
  * properties will be translated with the dgettext function using the current
@@ -621,9 +661,9 @@ EOAPI void efl_access_object_translation_domain_set(Eo *obj, const char *domain)
  * @ingroup Efl_Access_Object
  */
 EOAPI const char *efl_access_object_translation_domain_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Type of accessibility object
  *
@@ -633,9 +673,9 @@ EOAPI const char *efl_access_object_translation_domain_get(const Eo *obj);
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_access_type_set(Eo *obj, Efl_Access_Type type);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Type of accessibility object
  *
@@ -646,9 +686,9 @@ EOAPI void efl_access_object_access_type_set(Eo *obj, Efl_Access_Type type);
  * @ingroup Efl_Access_Object
  */
 EOAPI Efl_Access_Type efl_access_object_access_type_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Defines the relationship between two accessible objects.
  *
@@ -659,8 +699,9 @@ EOAPI Efl_Access_Type efl_access_object_access_type_get(const Eo *obj);
  * customized feedback, improving overall user experience.
  *
  * Relationship_append API is asymmetric, which means that appending, for
- * example, relation EFL_ACCESS_RELATION_FLOWS_TO from object A to B, do NOT
- * append relation EFL_ACCESS_RELATION_FLOWS_FROM from object B to object A.
+ * example, relation EFL_ACCESS_RELATION_TYPE_FLOWS_TO from object A to B, do
+ * NOT append relation EFL_ACCESS_RELATION_TYPE_FLOWS_FROM from object B to
+ * object A.
  *
  * @param[in] obj The object.
  * @param[in] type Relation type
@@ -672,13 +713,14 @@ EOAPI Efl_Access_Type efl_access_object_access_type_get(const Eo *obj);
  * @ingroup Efl_Access_Object
  */
 EOAPI Eina_Bool efl_access_object_relationship_append(Eo *obj, Efl_Access_Relation_Type type, const Efl_Access_Object *relation_object);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Removes the relationship between two accessible objects.
  *
- * If relation_object is NULL function removes all relations of the given type.
+ * If relation_object is @c NULL function removes all relations of the given
+ * type.
  *
  * @param[in] obj The object.
  * @param[in] type Relation type
@@ -687,26 +729,26 @@ EOAPI Eina_Bool efl_access_object_relationship_append(Eo *obj, Efl_Access_Relati
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_relationship_remove(Eo *obj, Efl_Access_Relation_Type type, const Efl_Access_Object *relation_object);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /** Removes all relationships in accessible object.
  *
  * @ingroup Efl_Access_Object
  */
 EOAPI void efl_access_object_relationships_clear(Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_ACCESS_OBJECT_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get root object of accessible object hierarchy
+ * @brief Root object of accessible object hierarchy
  *
  * @return Root object
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Efl_Object *efl_access_object_access_root_get(const Eo *obj);
-#endif
+EOAPI Efl_Object *efl_access_object_access_root_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 EWAPI extern const Efl_Event_Description _EFL_ACCESS_OBJECT_EVENT_PROPERTY_CHANGED;
 
@@ -776,5 +818,6 @@ EWAPI extern const Efl_Event_Description _EFL_ACCESS_OBJECT_EVENT_REMOVED;
  * @ingroup Efl_Access_Object
  */
 #define EFL_ACCESS_OBJECT_EVENT_REMOVED (&(_EFL_ACCESS_OBJECT_EVENT_REMOVED))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
