@@ -3,7 +3,7 @@
  * @ingroup Elementary
  *
  * Elementary configuration is formed by a set options bounded to a
- * given @ref Profile profile, like @ref Theme theme, @ref Fingers
+ * given @ref Elm_Profile, like @ref Elm_Theme, @ref Elm_Fingers
  * "finger size", etc. These are functions with which one synchronizes
  * changes made to those values to the configuration storing files, de
  * facto. You most probably don't want to use the functions in this
@@ -186,7 +186,7 @@ EAPI void        elm_config_profile_save(const char *profile);
  * @p derive_options string.
  *
  * At this point it is not expected that anyone would generally use this API
- * except if you are a destktop environment and so the user base of this API
+ * except if you are a desktop environment and so the user base of this API
  * will be enlightenment itself.
  *
  * @param profile The new profile's name
@@ -207,7 +207,7 @@ EAPI void        elm_config_profile_derived_add(const char *profile, const char
  * from the current profile.
  *
  * At this point it is not expected that anyone would generally use this API
- * except if you are a destktop environment and so the user base of this API
+ * except if you are a desktop environment and so the user base of this API
  * will be enlightenment itself.
  *
  * @param profile The profile's name that is to be deleted
@@ -301,6 +301,9 @@ EAPI void         elm_config_scroll_page_scroll_friction_set(double friction);
  * Get enable status of context menu disabled.
  *
  * @see elm_config_context_menu_disabled_set()
+ *
+ * @return @c EINA_TRUE if context menu is disabled, otherwise @c EINA_FALSE.
+ *
  * @ingroup Elm_Entry
  * @since 1.17
  */
@@ -460,7 +463,7 @@ EAPI void         elm_config_scroll_thumbscroll_momentum_threshold_set(double th
  *
  * @ingroup Elm_Scrolling
  */
-EAPI unsigned int elm_config_scroll_thumbscroll_flick_distance_tolerance_get(void);
+EAPI unsigned int elm_config_scroll_thumbscroll_momentum_distance_max_get(void);
 
 /**
  * Set the number of pixels the maximum distance which can be flicked.
@@ -469,75 +472,31 @@ EAPI unsigned int elm_config_scroll_thumbscroll_flick_distance_tolerance_get(voi
  *
  * @param distance the thumb scroll maximum flick distance
  *
- * @see elm_config_thumbscroll_flick_distance_tolerance_get()
+ * @see elm_config_thumbscroll_momentum_distance_max_get()
  * @ingroup Elm_Scrolling
  */
-EAPI void         elm_config_scroll_thumbscroll_flick_distance_tolerance_set(unsigned int distance);
+EAPI void         elm_config_scroll_thumbscroll_momentum_distance_max_set(unsigned int distance);
 
 /**
- * Get the amount of inertia a scroller will impose at self scrolling
- * animations.
+ * Get the scale ratio of geometric sequence as a kind of inertia a scroller
+ * will impose at self scrolling animations.
  *
  * @return the thumb scroll friction
  *
  * @ingroup Elm_Scrolling
  */
-EAPI double       elm_config_scroll_thumbscroll_friction_get(void);
+EAPI double       elm_config_scroll_thumbscroll_momentum_friction_get(void);
 
 /**
- * Set the amount of inertia a scroller will impose at self scrolling
- * animations.
+ * Set the scale ratio of geometric sequence as a kind of inertia a scroller
+ * will impose at self scrolling animations.
  *
  * @param friction the thumb scroll friction
  *
- * @see elm_config_thumbscroll_friction_get()
+ * @see elm_config_thumbscroll_momentum_friction_get()
  * @ingroup Elm_Scrolling
  */
-EAPI void         elm_config_scroll_thumbscroll_friction_set(double friction);
-
-/**
- * Get the min amount of inertia a scroller will impose at self scrolling
- * animations.
- *
- * @return the thumb scroll min friction
- *
- * @ingroup Elm_Scrolling
- */
-EAPI double       elm_config_scroll_thumbscroll_min_friction_get(void);
-
-/**
- * Set the min amount of inertia a scroller will impose at self scrolling
- * animations.
- *
- * @param friction the thumb scroll min friction
- *
- * @see elm_config_thumbscroll_min_friction_get()
- * @ingroup Elm_Scrolling
- */
-EAPI void         elm_config_scroll_thumbscroll_min_friction_set(double friction);
-
-/**
- * Get the standard velocity of the scroller. The scroll animation time is
- * same with thumbscroll friction, if the velocity is same with standard
- * velocity.
- *
- * @return the thumb scroll friction
- *
- * @ingroup Elm_Scrolling
- */
-EAPI double       elm_config_scroll_thumbscroll_friction_standard_get(void);
-
-/**
- * Set the standard velocity of the scroller. The scroll animation time is
- * same with thumbscroll friction, if the velocity is same with standard
- * velocity.
- *
- * @param standard the thumb scroll friction standard
- *
- * @see elm_config_thumbscroll_friction_standard_get()
- * @ingroup Elm_Scrolling
- */
-EAPI void         elm_config_scroll_thumbscroll_friction_standard_set(double standard);
+EAPI void         elm_config_scroll_thumbscroll_momentum_friction_set(double friction);
 
 /**
  * Get the amount of lag between your actual mouse cursor dragging
@@ -637,7 +596,7 @@ EAPI Eina_Bool    elm_config_scroll_animation_disabled_get(void);
  * This option disables timed animations during scrolling and forces scroll actions
  * to be performed immediately.
  * 
- * @param disable The state of this option
+ * @param enable The state of this option
  * 
  * @see elm_config_scroll_animation_disabled_get()
  *
@@ -692,9 +651,9 @@ EAPI double       elm_config_scroll_thumbscroll_smooth_amount_get(void);
  *
  * Scrolling with your finger can be smoothed out and the amount to smooth
  * is determined by this parameter. 0.0 means to not smooth at all and
- * 1.0 is to smoth as much as possible.
+ * 1.0 is to smooth as much as possible.
  * 
- * @param the amount to smooth from 0.0 to 1.0 with 0.0 being none
+ * @param amount the amount to smooth from 0.0 to 1.0 with 0.0 being none
  *
  * @see elm_config_thumbscroll_acceleration_threshold_set()
  * 
@@ -722,7 +681,7 @@ EAPI double       elm_config_scroll_thumbscroll_smooth_time_window_get(void);
  * to look at is determined by this config. The value is in seconds and
  * is from 0.0 to 1.0
  * 
- * @param the time window in seconds (between 0.0 and 1.0)
+ * @param amount the time window in seconds (between 0.0 and 1.0)
  *
  * @see elm_config_scroll_thumbscroll_smooth_time_window_get()
  * 
@@ -792,6 +751,148 @@ EAPI double       elm_config_scroll_thumbscroll_acceleration_weight_get(void);
  */
 EAPI void         elm_config_scroll_thumbscroll_acceleration_weight_set(double weight);
 
+/**
+ * Get the min limit for the momentum animation duration(unit:second)
+ *
+ * @return the thumb scroll momentum animation duration min limit
+ *
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_momentum_animation_duration_min_limit_get(void);
+
+/**
+ * Set the min limit for the momentum animation duration(unit:second)
+ *
+ * @param min the thumb scroll momentum animation duration min limit
+ *
+ * @see elm_config_scroll_thumbscroll_acceleration_weight_set()
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_momentum_animation_duration_min_limit_set(double min);
+
+/**
+ * Get the max limit for the momentum animation duration(unit:second)
+ *
+ * @return the thumb scroll momentum animation duration max limit
+ *
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_momentum_animation_duration_max_limit_get(void);
+
+/**
+ * Set the max limit for the momentum animation duration(unit:second)
+ *
+ * @param max the thumb scroll momentum animation duration max limit
+ *
+ * @see elm_config_scroll_thumbscroll_momentum_animation_duration_max_limit_get()
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_momentum_animation_duration_max_limit_set(double max);
+
+/**
+ * Get the min amount of inertia a scroller will impose at self scrolling
+ * animations.
+ *
+ * @return the thumb scroll min friction
+ *
+ * @deprecated
+ *
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_min_friction_get(void);
+
+/**
+ * Set the min amount of inertia a scroller will impose at self scrolling
+ * animations.
+ *
+ * @param friction the thumb scroll min friction
+ *
+ * @deprecated
+ *
+ * @see elm_config_thumbscroll_min_friction_get()
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_min_friction_set(double friction);
+
+/**
+ * Get the standard velocity of the scroller. The scroll animation time is
+ * same with thumbscroll friction, if the velocity is same with standard
+ * velocity.
+ *
+ * @return the thumb scroll friction
+ *
+ * @deprecated
+ *
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_friction_standard_get(void);
+
+/**
+ * Set the standard velocity of the scroller. The scroll animation time is
+ * same with thumbscroll friction, if the velocity is same with standard
+ * velocity.
+ *
+ * @param standard the thumb scroll friction standard
+ *
+ * @deprecated
+ *
+ * @see elm_config_thumbscroll_friction_standard_get()
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_friction_standard_set(double standard);
+
+/**
+ * Get the number of pixels the maximum distance which can be flicked.
+ * If it is flicked more than this,
+ * the flick distance is same with maximum distance.
+ *
+ * @return the thumb scroll maximum flick distance
+ *
+ * @deprecated
+ *
+ * @ingroup Elm_Scrolling
+ */
+EAPI unsigned int elm_config_scroll_thumbscroll_flick_distance_tolerance_get(void);
+
+/**
+ * Set the number of pixels the maximum distance which can be flicked.
+ * If it is flicked more than this,
+ * the flick distance is same with maximum distance.
+ *
+ * @param distance the thumb scroll maximum flick distance
+ *
+ * @deprecated
+ *
+ * @see elm_config_thumbscroll_flick_distance_tolerance_get()
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_flick_distance_tolerance_set(unsigned int distance);
+
+/**
+ * Get the amount of inertia a scroller will impose at self scrolling
+ * animations.
+ *
+ * @return the thumb scroll friction
+ *
+ * @deprecated
+ *
+ * @ingroup Elm_Scrolling
+ */
+EAPI double       elm_config_scroll_thumbscroll_friction_get(void);
+
+/**
+ * Set the amount of inertia a scroller will impose at self scrolling
+ * animations.
+ *
+ * @param friction the thumb scroll friction
+ *
+ * @deprecated
+ *
+ * @see elm_config_thumbscroll_friction_get()
+ * @ingroup Elm_Scrolling
+ */
+EAPI void         elm_config_scroll_thumbscroll_friction_set(double friction);
+
 /**
  * Get focus auto scroll mode.
  *
@@ -799,6 +900,10 @@ EAPI void         elm_config_scroll_thumbscroll_acceleration_weight_set(double w
  * elementary will automatically scroll the focused area to the visible
  * viewport.
  *
+ * @return ELM_FOCUS_AUTOSCROLL_MODE_SHOW if directly show the focused region or item automatically.
+ *  ELM_FOCUS_AUTOSCROLL_MODE_NONE if do not show the focused region or item automatically.
+ *  ELM_FOCUS_AUTOSCROLL_MODE_BRING_IN if bring_in the focused region or item automatically which might invole the scrolling.
+ *
  * @see elm_config_focus_autoscroll_mode_set()
  * @ingroup Elm_Focus
  * @since 1.10
@@ -826,7 +931,6 @@ EAPI void         elm_config_focus_autoscroll_mode_set(Elm_Focus_Autoscroll_Mode
 /**
  * Sets the slider's indicator visible mode.
  *
- * @param obj The slider object.
  * @param mode Elm_Slider_Indicator_Visible_Mode.
  * viewport.
  *
@@ -838,7 +942,6 @@ EAPI void elm_config_slider_indicator_visible_mode_set(Elm_Slider_Indicator_Visi
 /**
  * Get the slider's indicator visible mode.
  *
- * @param obj The slider object.
  * @return @c ELM_SLIDER_INDICATOR_VISIBLE_MODE_DEFAULT if not set anything by the user.
  * @c ELM_SLIDER_INDICATOR_VISIBLE_MODE_ALWAYS, ELM_SLIDER_INDICATOR_VISIBLE_MODE_ON_FOCUS,
  *    ELM_SLIDER_INDICATOR_VISIBLE_MODE_NONE if any of the above is set by user.
@@ -852,6 +955,15 @@ EAPI Elm_Slider_Indicator_Visible_Mode elm_config_slider_indicator_visible_mode_
  * @}
  */
 
+/**
+ * @defgroup longpress_group Longpress
+ * @ingroup Elementary
+ *
+ * @brief Configuration for longpress events.
+ *
+ * @{
+ */
+
 /**
  * Get the duration for occurring long press event.
  *
@@ -863,11 +975,24 @@ EAPI double       elm_config_longpress_timeout_get(void);
 /**
  * Set the duration for occurring long press event.
  *
- * @param lonpress_timeout Timeout for long press event
+ * @param longpress_timeout Timeout for long press event
  * @ingroup Longpress
  */
 EAPI void         elm_config_longpress_timeout_set(double longpress_timeout);
 
+/**
+ * @}
+ */
+
+/**
+ * @defgroup softcursor_group SotfCursor
+ * @ingroup Elementary
+ *
+ * @brief Configuration for softcursor.
+ *
+ * @{
+ */
+
 /**
  * Set the mode used for software provided mouse cursors inline in the window
  * canvas.
@@ -876,7 +1001,7 @@ EAPI void         elm_config_longpress_timeout_set(double longpress_timeout);
  * canvas windows in the event the native display system does not provide one
  * or the native one is not wanted.
  *
- * @param lonpress_timeout Timeout for long press event
+ * @param mode The mode for software cursors
  * @ingroup Softcursor
  *
  * @see elm_config_softcursor_mode_get()
@@ -895,6 +1020,15 @@ EAPI void         elm_config_softcursor_mode_set(Elm_Softcursor_Mode mode);
  */
 EAPI Elm_Softcursor_Mode elm_config_softcursor_mode_get(void);
 
+/**
+ * @}
+ */
+
+/**
+ * @ingroup Elm_Tooltips
+ * @{
+ */
+
 /**
  * Get the duration after which tooltip will be shown.
  *
@@ -909,6 +1043,10 @@ EAPI double      elm_config_tooltip_delay_get(void);
  */
 EAPI void        elm_config_tooltip_delay_set(double delay);
 
+/**
+ * @}
+ */
+
 /**
  * Get the configured cursor engine only usage
  *
@@ -957,7 +1095,7 @@ EAPI void   elm_config_scale_set(double scale);
  * Get the icon theme the user has set.
  *
  * This gets the global icon theme currently set or the default value
- * ELM_CONFIG_ICON_THEME_ELEMENTARY.
+ * #ELM_CONFIG_ICON_THEME_ELEMENTARY.
  *
  * @return the icon theme to use
  * @ingroup Elm_Icon
@@ -970,9 +1108,9 @@ EAPI const char *elm_config_icon_theme_get(void);
  *
  * This method will set the icon theme for all elm_icon_standard_set calls.
  * Valid parameters are the name of an installed freedesktop.org icon theme
- * or ELM_CONFIG_ICON_THEME_ELEMENTARY for the built in theme.
+ * or #ELM_CONFIG_ICON_THEME_ELEMENTARY for the built in theme.
  *
- * @param the name of a freedesktop.org icon theme or ELM_CONFIG_ICON_THEME_ELEMENTARY
+ * @param theme the name of a freedesktop.org icon theme or #ELM_CONFIG_ICON_THEME_ELEMENTARY
  * @ingroup Elm_Icon
  * @since 1.18
  */
@@ -1209,6 +1347,7 @@ EAPI Eina_List *elm_config_text_classes_list_get(void);
 /**
  * Free Elementary's list of supported text classes.
  *
+ * @param list The text classes list.
  * @ingroup Elm_Fonts
  *
  * @see elm_config_text_classes_list_get().
@@ -1335,6 +1474,7 @@ EAPI void             elm_config_font_overlay_apply(void);
  * EVAS_FONT_HINTING_AUTO < Automatic font hinting
  * EVAS_FONT_HINTING_BYTECODE < Bytecode font hinting
  *
+ * @param type The font hinting type
  * @ingroup Elm_Fonts
  *
  * This applies font hint changes to all windows of the current application.
@@ -1532,6 +1672,26 @@ EAPI Eina_Bool  elm_config_vsync_get(void);
  */
 EAPI void       elm_config_vsync_set(Eina_Bool enabled);
 
+/**
+ * Get the configure flag that will define if a window aggressively drop its
+ * resources when minimized.
+ *
+ * @return if it does.
+ *
+ * @since 1.21
+ */
+EAPI Eina_Bool elm_config_agressive_withdrawn_get(void);
+
+/**
+ * Set the configure flag that will make a window aggressively drop its
+ * resources when minimized.
+ *
+ * @param enabled This should be @c EINA_TRUE if enabled, or @c EINA_FALSE if
+ * not.
+ * @since 1.21
+ */
+EAPI void elm_config_agressive_withdrawn_set(Eina_Bool enabled);
+
 /**
  * Get the acceleration override preference flag
  *
@@ -1827,6 +1987,7 @@ EAPI Eina_List *elm_config_color_classes_list_get(void);
 /**
  * Free Elementary's list of supported color classes.
  *
+ * @param list The list of color classes to freed
  * @ingroup Colors
  * @since 1.10
  *
@@ -1917,6 +2078,22 @@ EAPI void      elm_config_color_overlay_unset(const char *color_class);
  */
 EAPI void      elm_config_color_overlay_apply(void);
 
+/**
+ * Get the desktop style entry enabled state
+ *
+ * @return The desktop style enabled state for entries
+ * @since 1.23
+ */
+EAPI Eina_Bool elm_config_desktop_entry_get(void);
+
+/**
+ * Set the desktop style entry enabled state
+ *
+ * @param enable The desktop style enabled state for entries
+ * @since 1.23
+ */
+EAPI void elm_config_desktop_entry_set(Eina_Bool enable);
+
 /**
  * Get the magnifier enabled state for entries
  *
@@ -1973,7 +2150,7 @@ EAPI void      elm_config_audio_mute_set(Edje_Channel channel, Eina_Bool mute);
  * This determines if elementary will show a focus box indicating the focused
  * widget automatically if keyboard controls like "Tab" are used to switch
  * focus between widgets. Mouse or touch control will hide this auto shown
- * focus, unless focus display has been expliccitly forced on for the window.
+ * focus, unless focus display has been explicitly forced on for the window.
  *
  * @return The enabled state for auto focus display
  * @since 1.14
@@ -1986,7 +2163,7 @@ EAPI Eina_Bool elm_config_window_auto_focus_enable_get(void);
  * This determines if elementary will show a focus box indicating the focused
  * widget automatically if keyboard controls like "Tab" are used to switch
  * focus between widgets. Mouse or touch control will hide this auto shown
- * focus, unless focus display has been expliccitly forced on for the window.
+ * focus, unless focus display has been explicitly forced on for the window.
  *
  * @param enable the auto focus display enabled state
  * @since 1.14
@@ -2032,7 +2209,7 @@ EAPI Eina_Bool elm_config_popup_scrollable_get(void);
  * If scrollable is true, popup's contents is wrapped in a scroller container
  * in order to popup shouldn't be larger than its parent.
  *
- * @param enable the popup scroll
+ * @param scrollable enable the popup scroll
  * @since 1.18
  */
 EAPI void      elm_config_popup_scrollable_set(Eina_Bool scrollable);
@@ -2131,104 +2308,66 @@ EAPI void elm_config_web_backend_set(const char *backend);
  */
 EAPI const char *elm_config_web_backend_get(void);
 
+/**
+ * Get whether the system is offline
+ *
+ * @return True only if the system config is set as offline
+ *
+ * @since 1.21
+ * @see elm_config_offline_set()
+ */
+EAPI Eina_Bool elm_config_offline_get(void);
 
-/* new efl.config interface helpers in C */
+/**
+ * Set whether the system is offline
+ *
+ * @param set True only if the system is offline
+ *
+ * @since 1.21
+ * @see elm_config_offline_get()
+ */
+EAPI void elm_config_offline_set(Eina_Bool set);
 
-#ifdef EFL_EO_API_SUPPORT
+/**
+ * Get whether the system should be conserving power
+ *
+ * @return Values greater than 0 if power is being conserved; higher numbers indicate greater conservation
+ *
+ * @since 1.21
+ * @see elm_config_powersave_set()
+ */
+EAPI int elm_config_powersave_get(void);
 
-static inline Eina_Bool
-efl_config_bool_set(Efl_Config *obj, const char * name, Eina_Bool val)
-{
-   Eina_Value *v = eina_value_new(EINA_VALUE_TYPE_UCHAR);
-   Eina_Bool b;
-   eina_value_set(v, val);
-   b = efl_config_set(obj, name, v);
-   eina_value_free(v);
-   return b;
-}
+/**
+ * Set whether the system should be conserving power
+ *
+ * @param set Values greater than 0 if power is being conserved; higher numbers indicate greater conservation
+ *
+ * @since 1.21
+ * @see elm_config_powersave_set()
+ */
+EAPI void elm_config_powersave_set(int set);
 
-static inline Eina_Bool
-efl_config_bool_get(const Efl_Config *obj, const char * name)
-{
-   Eina_Value *v = efl_config_get(obj, name);
-   Eina_Bool b = 0;
-   if (eina_value_type_get(v) == EINA_VALUE_TYPE_UCHAR)
-     eina_value_get(v, &b);
-   eina_value_free(v);
-   return b;
-}
+/**
+  * Get the animation duration for container objects
+  *
+  * @return Animation duration
+  *
+  * @since 1.21
+  * @see elm_config_drag_anim_duration_set()
+  */
+EAPI double elm_config_drag_anim_duration_get(void);
 
-static inline Eina_Bool
-efl_config_int_set(Efl_Config *obj, const char * name, int val)
-{
-   Eina_Value *v = eina_value_new(EINA_VALUE_TYPE_INT);
-   Eina_Bool b;
-   eina_value_set(v, val);
-   b = efl_config_set(obj, name, v);
-   eina_value_free(v);
-   return b;
-}
+/**
+  * Set the animation duration for container objects
+  *
+  * @param set Animation duration
+  *
+  * @since 1.21
+  * @see elm_config_drag_anim_duration_get()
+  */
+EAPI void elm_config_drag_anim_duration_set(double set);
 
-static inline int
-efl_config_int_get(const Efl_Config *obj, const char * name)
-{
-   Eina_Value *v = efl_config_get(obj, name);
-   int b = 0;
-   if (eina_value_type_get(v) == EINA_VALUE_TYPE_INT)
-     eina_value_get(v, &b);
-   eina_value_free(v);
-   return b;
-}
-
-static inline Eina_Bool
-efl_config_double_set(Efl_Config *obj, const char * name, double val)
-{
-   Eina_Value *v = eina_value_new(EINA_VALUE_TYPE_DOUBLE);
-   Eina_Bool b;
-   eina_value_set(v, val);
-   b = efl_config_set(obj, name, v);
-   eina_value_free(v);
-   return b;
-}
-
-static inline double
-efl_config_double_get(const Efl_Config *obj, const char * name)
-{
-   Eina_Value *v = efl_config_get(obj, name);
-   double b = 0;
-   if (eina_value_type_get(v) == EINA_VALUE_TYPE_DOUBLE)
-     eina_value_get(v, &b);
-   eina_value_free(v);
-   return b;
-}
-
-static inline Eina_Bool
-efl_config_string_set(Efl_Config *obj, const char *name, const char *val)
-{
-   Eina_Value *v = eina_value_new(EINA_VALUE_TYPE_STRING);
-   Eina_Bool b;
-   eina_value_set(v, val);
-   b = efl_config_set(obj, name, v);
-   eina_value_free(v);
-   return b;
-}
-
-static inline Eina_Stringshare *
-efl_config_string_get(const Efl_Config *obj, const char *name)
-{
-   Eina_Value *v = efl_config_get(obj, name);
-   Eina_Stringshare *s = 0;
-   if (eina_value_type_get(v) == EINA_VALUE_TYPE_STRING)
-     {
-        const char *b = 0;
-        eina_value_get(v, &b);
-        s = eina_stringshare_add(b);
-     }
-   eina_value_free(v);
-   return s;
-}
-
-#endif
 
 /**
  * @}
