@@ -44,6 +44,17 @@ EOAPI Efl_Canvas_Vg_Node *efl_canvas_vg_container_child_get(Eo *obj, const char
  * @ingroup Efl_Canvas_Vg_Container
  */
 EOAPI Eina_Iterator *efl_canvas_vg_container_children_get(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @brief Get all children of container
+ *
+ * @param[in] obj The object.
+ *
+ * @return List to children
+ *
+ * @ingroup Efl_Canvas_Vg_Container
+ */
+EOAPI const Eina_List *efl_canvas_vg_container_children_direct_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
